Module blaxel.models.policy_max_tokens
======================================

Classes
-------

`PolicyMaxTokens(granularity: blaxel.types.Unset | str = <blaxel.types.Unset object>, input_: blaxel.types.Unset | int = <blaxel.types.Unset object>, output: blaxel.types.Unset | int = <blaxel.types.Unset object>, ratio_input_over_output: blaxel.types.Unset | int = <blaxel.types.Unset object>, step: blaxel.types.Unset | int = <blaxel.types.Unset object>, total: blaxel.types.Unset | int = <blaxel.types.Unset object>)`
:   PolicyMaxTokens is a local type that wraps a slice of PolicyMaxTokens
    
    Attributes:
        granularity (Union[Unset, str]): Granularity
        input_ (Union[Unset, int]): Input
        output (Union[Unset, int]): Output
        ratio_input_over_output (Union[Unset, int]): RatioInputOverOutput
        step (Union[Unset, int]): Step
        total (Union[Unset, int]): Total
    
    Method generated by attrs for class PolicyMaxTokens.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `granularity: blaxel.types.Unset | str`
    :

    `input_: blaxel.types.Unset | int`
    :

    `output: blaxel.types.Unset | int`
    :

    `ratio_input_over_output: blaxel.types.Unset | int`
    :

    `step: blaxel.types.Unset | int`
    :

    `total: blaxel.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :